@@ -44,7 +44,7 @@ class ActiveConnection(BaseConnection):
         self.__address = address
         # lock for connecting
         self.__lock = threading.RLock()
-        self.__connecting = False
+        self.__connecting = 0
 
     def __connect(self) -> bool:
         self.status = ConnectionStatus.Connecting
@@ -61,22 +61,31 @@ class ActiveConnection(BaseConnection):
 
     def __reconnect(self) -> bool:
         with self.__lock:
-            if self._sock is None and not self.__connecting:
-                try:
-                    self.__connecting = True
+            try:
+                self.__connecting += 1
+                if self.__connecting == 1 and self._sock is None:
                     redo = self.__connect()
-                finally:
-                    self.__connecting = False
-                return redo
+                else:
+                    redo = False
+            finally:
+                self.__connecting -= 1
+            return redo
 
     @property
     def socket(self) -> Optional[socket.socket]:
         """ Get connected socket """
-        self.__reconnect()
-        # call super()
-        if self._is_alive():
+        if self.alive:
+            self.__reconnect()
             return self._sock
 
+    @property
+    def address(self) -> Optional[tuple]:
+        return self.__address
+
+    @property
+    def alive(self) -> bool:
+        return self._running
+
     def _receive(self) -> Optional[bytes]:
         data = super()._receive()
         if data is None and self.__reconnect():
@@ -90,7 +99,3 @@ class ActiveConnection(BaseConnection):
             # try again
             res = super().send(data=data)
         return res
-
-    @property
-    def running(self) -> bool:
-        return self._running
