@@ -78,15 +78,23 @@ class BaseConnection(Connection):
     @property
     def socket(self) -> Optional[socket.socket]:
         """ Get connected socket """
-        if self._is_alive():
+        if self.alive:
             return self._sock
 
-    def _is_alive(self) -> bool:
+    @property
+    def address(self) -> Optional[tuple]:
         sock = self._sock
-        if sock is None or getattr(sock, '_closed', False):
-            return False
-        else:
-            return True
+        if sock is not None:
+            return sock.getpeername()
+
+    @property
+    def alive(self) -> bool:
+        if self._running:
+            sock = self._sock
+            if sock is None or getattr(sock, '_closed', False):
+                return False
+            else:
+                return True
 
     def __write(self, data: bytes) -> int:
         # sock.sendall(data)
@@ -175,10 +183,6 @@ class BaseConnection(Connection):
             if delegate is not None:
                 delegate.connection_changed(connection=self, old_status=old, new_status=value)
 
-    @property
-    def running(self) -> bool:
-        return self._running and self._is_alive()
-
     #
     #   Running
     #
@@ -200,6 +204,7 @@ class BaseConnection(Connection):
 
     def finish(self):
         """ Cleanup after handling """
+        self._running = False
         if self._sock is not None:
             # shutdown socket
             self.__close()
@@ -209,7 +214,7 @@ class BaseConnection(Connection):
         """ Handling for receiving data packages
             (it will call 'process()' circularly)
         """
-        while self.running:
+        while self.alive:
             s = self.status
             if s in [ConnectionStatus.Connected, ConnectionStatus.Maintaining, ConnectionStatus.Expired]:
                 working = self.process()
@@ -222,19 +227,21 @@ class BaseConnection(Connection):
         """ Try to receive one data package,
             which will be cached into a memory pool
         """
+        # 0. check empty spaces
+        spaces = self.__pool.spaces
+        if spaces < 1024:
+            # not enough spaces
+            return False
         # 1. try to read bytes
         data = self._receive()
         if data is None or len(data) == 0:
             return False
         # 2. cache it
-        ejected = self.__pool.cache(data=data)
+        self.__pool.cache(data=data)
         delegate = self.delegate
-        if delegate is None:
-            return True
-        # 3. callback
-        if ejected is not None:
-            delegate.connection_overflowed(connection=self, ejected=ejected)
-        delegate.connection_received(connection=self, data=data)
+        if delegate is not None:
+            # 3. callback
+            delegate.connection_received(connection=self, data=data)
         return True
 
     # noinspection PyMethodMayBeStatic
