@@ -68,6 +68,16 @@ class Connection:
         """
         raise NotImplemented
 
+    @property
+    def address(self) -> Optional[tuple]:
+        """ Get remote address (host:port) """
+        raise NotImplemented
+
+    @property
+    def alive(self) -> bool:
+        """ Check whether connection is alive: the thread is still running """
+        raise NotImplemented
+
     @property
     def status(self) -> ConnectionStatus:
         """ Get status """
